@@ -162,6 +162,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.wildness,
 			QtCore.SIGNAL("valueChanged(double)"),
 			lambda x: self.ui.wildslide.setValue(int(x * 10)))
+		self.connect(self.ui.copyblock,
+			QtCore.SIGNAL("clicked()"),
+			self.copy_block)
+		self.connect(self.ui.copyinstrument,
+			QtCore.SIGNAL("clicked()"),
+			self.copy_instrument)
 		self.connect(self.ui.copyprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.copy_progression)
@@ -218,6 +224,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if i >= 0:
 			self.ui.blocks.takeItem(i)
 
+	def copy_block(self):
+		i = self.ui.blocks.currentRow()
+		if i >= 0:
+			self.ui.blocks.addItem(self.ui.blocks.item(i).text())
+
 	def add_progression(self):
 		self.ui.progressions.addItem(
 			self.ui.progressioncombo.currentText())
@@ -315,6 +326,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if i >= 0:
 			self.ui.instruments.takeItem(i)
 
+	def copy_instrument(self):
+		i = self.ui.instruments.currentRow()
+		if i >= 0:
+			self.ui.instruments.addItem(self.ui.instruments.item(i).text())
+
+
 	def edit_block(self):
 		cur = self.ui.blocks.item(self.ui.blocks.currentRow())
 		if cur is None:
