@@ -5,16 +5,16 @@ from qtGUI.MainWindow import ImproviserMainWindow
 from qtGUI.PreferencesDialog import PreferencesDialog
 from sys import argv
 
-def show_main(no_sound = True, soundfont = '', driver=''):
+def show_main(params):
 	i = ImproviserMainWindow()
-	if no_sound:
+	if 'soundfont' not in params:
 		i.no_fluidsynth = True
 		i.soundfont = ''
 		i.driver = ''
 	else:
 		i.no_fluidsynth = False
-		i.soundfont = soundfont
-		i.driver = driver
+		i.soundfont = params["soundfont"]
+		i.driver = params["driver"]
 	i.show()
 
 app = QtGui.QApplication(argv)
